Documentation
¶
Overview ¶
Package kdtree provides a generic kd-tree implementation.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultOptions = Options{
MaxDepth: 64,
LeafSize: 2,
FaultTolerance: 2,
ClipThreshold: 32,
}
Reasonable build options
Functions ¶
This section is empty.
Types ¶
type Node ¶
type Node struct {
// contains filtered or unexported fields
}
Node represents nodes in a kd-tree, both interior and leaf.
type Options ¶
type Options struct {
MaxDepth int // MaxDepth limits how many levels the tree can have
LeafSize int // LeafSize is the desired leaf size. Some leaves may not obey this size.
FaultTolerance int // FaultTolerance specifies the number of bad splits before a branch is considered a fault.
ClipThreshold int // ClipThreshold specifies the maximum number of values in a node to do primitive clipping.
}
Options allows you to tune the parameters of kd-tree construction.
type Tree ¶
type Tree struct {
// contains filtered or unexported fields
}
Tree is a generic kd-tree.
Click to show internal directories.
Click to hide internal directories.