Documentation
¶
Overview ¶
Package log provides an interface for multi-level logging.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Criticalf ¶
func Criticalf(format string, args ...interface{})
Criticalf calls Criticalf on the default logger. Arguments are handled in the manner of fmt.Printf.
func Debugf ¶
func Debugf(format string, args ...interface{})
Debugf calls Debugf on the default logger. Arguments are handled in the manner of fmt.Printf.
func Errorf ¶
func Errorf(format string, args ...interface{})
Errorf calls Errorf on the default logger. Arguments are handled in the manner of fmt.Printf.
Types ¶
type Logger ¶
type Logger interface {
// Debugf formats its arguments according to the format, analogous to fmt.Printf,
// and records the text as a log message at Debug level.
Debugf(format string, args ...interface{})
// Infof is like Debugf, but at Info level.
Infof(format string, args ...interface{})
// Warningf is like Debugf, but at Warning level.
Warningf(format string, args ...interface{})
// Errorf is like Debugf, but at Error level.
Errorf(format string, args ...interface{})
// Criticalf is like Debugf, but at Critical level.
Criticalf(format string, args ...interface{})
}
A type that implements Logger can output multi-level log messages.
Click to show internal directories.
Click to hide internal directories.